#!/bin/sh
#
# test.sh
#

printf  "\ntest/ping 172.25.0.4\n"
test/ping 172.25.0.4

printf  "\ntest/udpcli 172.25.0.4\n"
printf  "Exec server program and type key.\n"
read dummy
test/udpcli 172.25.0.4

printf  "\ntest/udpserv\n"
test/udpserv

printf  "\ntest/udpservselect\n"
test/udpservselect

printf  "\ntest/tcpcli 172.25.0.4\n"
printf  "Exec server program and type key.\n"
read dummy
test/tcpcli 172.25.0.4

printf  "\ntest/tcpcliselect 172.25.0.4\n"
test/tcpcliselect 172.25.0.4

printf  "\ntest/tcpserv\n"
test/tcpserv

printf  "\ntest/tcpservselect\n"
test/tcpservselect

printf  "\ntest/tcpservpoll\n"
test/tcpservpoll

printf  "\ngcc test.c\n"
gcc test.c

printf  "\na.out\n"
./a.out
rm a.out

#եåԡɥ饤Сܿޤα
#printf  "\ndd if=/dev/fd0 of=fd count=200\n"
#dd if=/dev/fd0 of=fd count=200
#rm fd

printf  "\nftp 172.25.0.4\n"
ftp 172.25.0.4
rm test.dat

printf  "\ntest/brk\n"
test/brk

printf  "\ntest/read\n"
test/read

printf  "\ntest/write\n"
test/write

printf  "\ntest/pthread_create\n"
test/pthread_create

printf  "\ntest/pthread_join\n"
test/pthread_join

printf  "\ntest/vm\n"
test/vm

printf  "\ntest/testThread\n"
test/testThread

printf  "\ntestCache\n"
test/testCache
rm test11.dat
rm test21.dat
rm test31.dat
